@@ -1,14 +1,6 @@
-##' A complementary package to the FAOSTAT database and the
-##' Statistical Yearbook of the Food and Agricultural Organization of
-##' the United Nations.
-##'
-##'
-##' @name FAOSTAT-package
-##' @docType package
 ##' @title A complementary package to the FAOSTAT database and the
 ##' Statistical Yearbook of the Food and Agricultural Organization of
 ##' the United Nations.
-##' @author Michael. C. J. Kao \email{michael.kao@@fao.org}
 ##' @keywords package
 ##' @import RJSONIO
 ##' @import plyr
@@ -17,7 +9,7 @@
 ##' @import classInt
 ##' @import labeling
 ##' @import httr
-##'
+"_PACKAGE"
 
 .FAOSTATenv <- new.env()
 # Remove CHECK note due to non-standard evaluation in data.table
