@@ -6,6 +6,16 @@
 #' @param data object. Data to be cached
 #' @param reset logical. Should the cache be replaced with new data?
 #' @keywords internal
+cache_data <- function(name, data, reset = FALSE, environment = .FAOSTATenv) {
+    if (check_cache(name, environment = environment) && !reset) {
+      cached <- cache_retrieve(name, environment = environment)
+      return(cached)
+    }
+    
+    assign(name, data, envir = environment)
+    
+    return(data)
+  }
 
 check_cache <- function(name, environment = .FAOSTATenv) {
   !is.null(environment[[name]])
@@ -19,14 +29,3 @@ cache_delete <- function(name, environment = .FAOSTATenv){
   rm(list = name, envir = environment)
 }
 
-cache_data <-
-  function(name, data, reset = FALSE, environment = .FAOSTATenv) {
-    if (check_cache(name, environment = environment) && !reset) {
-      cached <- cache_retrieve(name, environment = environment)
-      return(cached)
-    }
-    
-    assign(name, data, envir = environment)
-    
-    return(data)
-  }
